from typing import Any, Dict, Optional

import click

from gcs_cli.commands.storage_gateway._common import make_create_command
from gcs_cli.parsing import (
    box_options,
    globus_command,
    storage_gateway_create_and_update_params,
)
from gcs_cli.sdk_client.data import BoxStoragePolicies, StorageGatewayDocument
from gcs_cli.services.gcs import BOX_CONNECTOR_ID


@globus_command("box")
@storage_gateway_create_and_update_params(create=True)
@box_options
@make_create_command
def box_create(
    *,
    box_settings: Optional[Dict[str, Any]],
    box_client_id: Optional[str],
    box_client_secret: Optional[str],
    box_user_api_rate_limit: Optional[int],
    **kwargs: Any
) -> StorageGatewayDocument:
    """Create a new Box Storage Gateway"""
    if not box_settings and not box_client_id and not box_client_secret:
        raise click.UsageError(
            "Missing --box-settings or --box-client-id and --box-client-secret"
        )
    if box_settings and (box_client_id or box_client_secret):
        raise click.UsageError(
            "Use --box-settings or both --box-client-id and --box-client-secret"
        )
    args: Dict[str, Any] = {}
    policies = None
    if box_client_id is not None:
        args["client_id"] = box_client_id
    if box_client_secret is not None:
        args["secret"] = box_client_secret
    if box_settings is not None:
        args["enterpriseID"] = box_settings["enterpriseID"]
        args["boxAppSettings"] = box_settings["boxAppSettings"]
    if box_user_api_rate_limit is not None:
        args["user_api_rate_limit"] = box_user_api_rate_limit

    policies = BoxStoragePolicies(**args)

    return StorageGatewayDocument(
        connector_id=BOX_CONNECTOR_ID, policies=policies, **kwargs
    )
