from typing import Any, Iterable, Optional

from gcs_cli.commands.storage_gateway._common import make_create_command
from gcs_cli.parsing import (
    globus_command,
    posix_options,
    storage_gateway_create_and_update_params,
)
from gcs_cli.sdk_client.data import POSIXStoragePolicies, StorageGatewayDocument
from gcs_cli.services.gcs import POSIX_CONNECTOR_ID


@globus_command("posix", short_help="Create a new POSIX storage gateway")
@storage_gateway_create_and_update_params(create=True)
@posix_options(create=True)
@make_create_command
def posix_create(
    *,
    posix_group_allow: Optional[Iterable[str]],
    posix_group_deny: Optional[Iterable[str]],
    **kwargs: Any
) -> StorageGatewayDocument:
    """
    Create a new storage gateway. Requires a display name and a connector.
    Additional connector specific options may be required as well.
    """
    policies = POSIXStoragePolicies(
        groups_allow=posix_group_allow, groups_deny=posix_group_deny
    )
    return StorageGatewayDocument(
        connector_id=POSIX_CONNECTOR_ID, policies=policies, **kwargs
    )
