import uuid
from typing import Any, Iterable, Optional, Tuple

from gcs_cli.commands.storage_gateway._common import make_update_command
from gcs_cli.parsing import (
    globus_command,
    s3_options,
    storage_gateway_create_and_update_params,
    storage_gateway_id_arg,
)
from gcs_cli.sdk_client.data import S3StoragePolicies, StorageGatewayDocument
from gcs_cli.services.gcs import S3_CONNECTOR_ID


@globus_command("s3", short_help="Update an S3 Storage Gateway")
@storage_gateway_id_arg
@storage_gateway_create_and_update_params(create=False)
@s3_options
@make_update_command
def s3_update(
    storage_gateway_id: uuid.UUID,
    *,
    s3_endpoint: Optional[str],
    bucket: Optional[Iterable[str]],
    s3_user_credential: Optional[bool],
    **kwargs: Any
) -> Tuple[uuid.UUID, StorageGatewayDocument]:
    """
    Update an existing S3 Storage Gateway.
    Any options given will replace existing values in the storage gateway's definition.
    Any options not given will retain their existing values.
    """
    policies = None
    if any(x is not None for x in (s3_endpoint, bucket, s3_user_credential)):
        policies = S3StoragePolicies(
            s3_endpoint=s3_endpoint,
            s3_buckets=bucket,
            s3_user_credential_required=s3_user_credential,
        )

    return (
        storage_gateway_id,
        StorageGatewayDocument(
            connector_id=S3_CONNECTOR_ID, policies=policies, **kwargs
        ),
    )
