"""
Define a command decorator which requires the user be logged-in before running the
command.
"""

import functools
from typing import Any, Callable

import click

from gcs_cli.config import GCS_CLIENT_DATA_CONFIG_KEY, token_storage_adapter


def is_logged_in() -> bool:
    adapter = token_storage_adapter()
    return bool(adapter.read_config(GCS_CLIENT_DATA_CONFIG_KEY))


def requires_login(command: Callable) -> Callable:
    @functools.wraps(command)
    def wrapped(*args: Any, **kwargs: Any) -> Any:
        if not is_logged_in():
            raise click.ClickException(
                "You must login first, before running this command!"
            )
        return command(*args, **kwargs)

    return wrapped
