import click

from ..models import (
    CILogonConfiguration,
    GridmapConfiguration,
    MigrationPlan,
    MyProxyConfiguration,
)
from .decorators import requires_migration_plan


@click.command("list", help="List identity mapping configurations")
@requires_migration_plan
def identity_mapping_list(migration_plan: MigrationPlan) -> None:
    if not migration_plan.gsi_authz_configuration:
        raise click.ClickException("Migration plan has no GSI configuration")
    if not migration_plan.gsi_authz_configuration.callouts:
        raise click.ClickException("Migration plan has no callout configuration")
    if not migration_plan.storage_gateway:
        raise click.ClickException("Migration plan has no storage gateway")

    for idx, callout in enumerate(migration_plan.gsi_authz_configuration.callouts):
        if isinstance(callout, CILogonConfiguration):
            domains_list = [
                f"""{domain}{'*'
                if domain not in (migration_plan.storage_gateway.allowed_domains or [])
                else ""}"""
                for domain in (callout.domains or [])
            ]
            suffix = (
                click.style(" (requires_attention)", bold=True)
                if [d for d in domains_list if "*" in d] or not domains_list
                else ""
            )
            click.secho(f"mapping {idx}:{suffix}")
            click.echo(
                "\n".join(
                    [
                        "    type: CILogon",
                        f"    subject: {callout.dn}",
                        f"    organization: {callout.organization}",
                        f"    domains: {', '.join(domains_list)}",
                    ]
                )
            )
        elif isinstance(callout, MyProxyConfiguration):
            domains_list = [
                f"""{domain}{'*'
                if domain not in (migration_plan.storage_gateway.allowed_domains or [])
                else ""}"""
                for domain in callout.domains
            ]
            suffix = (
                click.style(" (requires_attention)", bold=True)
                if [d for d in domains_list if "*" in d] or not domains_list
                else ""
            )
            click.secho(f"mapping {idx}:{suffix}")
            click.echo(
                "\n".join(
                    [
                        "    type: MyProxy",
                        f"    subject: {callout.dn}",
                        f"    domains: {', '.join(domains_list)}",
                    ]
                )
            )
        elif isinstance(callout, GridmapConfiguration):
            domains_list = [
                f"""{domain}{'*'
                if domain not in (migration_plan.storage_gateway.allowed_domains or [])
                else ""}"""
                for domain in callout.domains
            ]
            suffix = (
                click.style(" (requires_attention)", bold=True)
                if [d for d in domains_list if "*" in d]
                or (callout.mappings and not domains_list)
                else ""
            )
            click.secho(f"mapping {idx}:{suffix}")
            click.echo(
                "\n".join(
                    [
                        "    type: Gridmap",
                        f"\tdomains: {', '.join(domains_list)}",
                        "\tmappings:",
                    ]
                    + [
                        f"    \t{subject}: {local_users}"
                        for subject, local_users in (callout.mappings or {}).items()
                    ]
                )
            )
