from flask import current_app

from globus.manager.api.errors import IdNotInIdentitySet
from .filter import Filter


class IdentityInIdentitySetFilter(Filter):
    """
    This class provides methods to filter out identities the identity set
    which do not match a requested identity id.
    """

    def __init__(self, id=None):
        self.id = id

    def __call__(self, identity_set, auth_state):
        """
        Filter the identity_set, removing all items whose `id` property
        does not match the id passed to this filter's constructor.

        :param identity_set:
            Identity set information, filtered in place
        :param auth_state:
            Authentication state for this request

        :returns: Returns the subset of identity_set_data which matches the
            id.
        """
        current_app.logger.debug("%s: input=%s", self, identity_set)
        invalid_identities = [i for i in identity_set if i["id"] != self.id]

        for i in invalid_identities:
            identity_set.remove(i)

        if invalid_identities or not identity_set:
            detail = IdNotInIdentitySet(id=self.id)
            identity_set.error_details.insert(0, detail)

        current_app.logger.debug(
            "%s: result id_set = %s", self, [i["id"] for i in identity_set]
        )
        return identity_set

    def __repr__(self):
        return "<IdentityInIdentitySetFilter {}>".format(self.id)
