from globus.manager.constants import ConfigurationObjectTag
import globus.manager.api.errors as errors
from . import UserCredential
from .decorators import checks_property


class CephUserCredential(UserCredential):
    POLICY_DATA_TYPE = "ceph_user_credential_policies#1.0.0"
    POLICY_DATA_TYPES = [POLICY_DATA_TYPE]
    CONNECTOR_ID = "1b6374b0-f6a4-4cf7-a26f-f262d9c6ca72"

    __mapper_args__ = {
        "polymorphic_identity": (
            ConfigurationObjectTag.USER_CREDENTIAL.name + CONNECTOR_ID
        )
    }

    def __init__(self, appsync_data=None, doc=None, storage_gateway=None):
        if doc:
            username = doc["username"]
            display_name = storage_gateway.get_user_display_name(username)
            if display_name is None:
                raise errors.InvalidUserError(username)

            policies = doc.get("policies")
            if not policies:
                policies = {"DATA_TYPE": self.POLICY_DATA_TYPE}
            doc = {
                **doc,
                **{
                    "display_name": display_name,
                    "invalid": doc.get("invalid", False),
                    "deleted": False,
                    "provisioned": True,
                    "policies": policies,
                },
            }

        super().__init__(
            appsync_data=appsync_data, doc=doc, storage_gateway=storage_gateway
        )

    @checks_property(prop="display_name")
    def check_display_name(self, value: str):
        old_value = getattr(self, "display_name", None)
        if old_value and value and old_value != value:
            raise AttributeError("display_name")

    def patch(self, **doc):
        display_name = doc.pop("display_name", getattr(self, "display_name", None))
        doc["display_name"] = display_name
        super().patch(**doc)

    def put(self, **doc):
        display_name = doc.pop("display_name", getattr(self, "display_name", None))
        doc["display_name"] = display_name
        super().put(**doc)

    @property
    def connector_id(self):
        return self.CONNECTOR_ID

    @connector_id.setter
    def connector_id(self, value):
        pass

    def __repr__(self):
        return "<CephUserCredential {}>".format(self.id)
