import uuid

import marshmallow as ma

from .data_type import DataTypeSchema
from .schema_version_checker import verify_schema_version


class EndpointSubscriptionSchema(ma.Schema):
    _DATA_TYPE = "endpoint_subscription#1.0.0"

    DATA_TYPE = ma.fields.String(required=True, allow_none=False, default=_DATA_TYPE)
    subscription_id = ma.fields.String(required=True, allow_none=True)

    @ma.validates("DATA_TYPE")
    def validate_data_type(self, data, **kwargs):
        verify_schema_version(data, self._DATA_TYPE)

    @ma.validates("subscription_id")
    def validate_subscription_id(self, data, **kwargs):
        if data:
            if data == "DEFAULT":
                return data
            else:
                try:
                    return uuid.UUID(data)
                except Exception:
                    raise ma.ValidationError('Value must be a UUID or "DEFAULT"')


endpoint_subscription_schema = EndpointSubscriptionSchema()
DataTypeSchema.register_schema(endpoint_subscription_schema)
