from ..api.collection import CollectionSchema
from ..api.storage_gateway import StorageGatewaySchema
from ..api.user_credential import UserCredentialSchema
from .s3 import (
    S3StoragePoliciesSchema,
    S3UserCredentialPoliciesSchema,
    S3CollectionPoliciesSchema,
)


ACTIVESCALE_CONNECTOR_ID = "7251f6c8-93c9-11eb-95ba-12704e0d6a4d"


class ActiveScaleStoragePoliciesSchema(S3StoragePoliciesSchema):
    connector_id = ACTIVESCALE_CONNECTOR_ID


class ActiveScaleCollectionPoliciesSchema(S3CollectionPoliciesSchema):
    connector_id = ACTIVESCALE_CONNECTOR_ID


class ActiveScaleUserCredentialPoliciesSchema(S3UserCredentialPoliciesSchema):
    connector_id = ACTIVESCALE_CONNECTOR_ID


activescale_storage_policies_schema = ActiveScaleStoragePoliciesSchema(
    load_only=ActiveScaleStoragePoliciesSchema.private
)
activescale_storage_policies_private_schema = ActiveScaleStoragePoliciesSchema()

activescale_user_credential_policies_private_schema = (
    ActiveScaleUserCredentialPoliciesSchema()
)
activescale_user_credential_policies_schema = ActiveScaleUserCredentialPoliciesSchema(
    load_only=ActiveScaleUserCredentialPoliciesSchema.private
)
activescale_collection_policies_schema = ActiveScaleCollectionPoliciesSchema(
    load_only=ActiveScaleCollectionPoliciesSchema.private
)
activescale_collection_policies_private_schema = ActiveScaleCollectionPoliciesSchema()

StorageGatewaySchema.register_schema(
    public=activescale_storage_policies_schema,
    private=activescale_storage_policies_private_schema,
)

UserCredentialSchema.register_schema(
    public=activescale_user_credential_policies_schema,
    private=activescale_user_credential_policies_private_schema,
)

CollectionSchema.register_schema(
    public=activescale_collection_policies_schema,
    private=activescale_collection_policies_private_schema,
)
