import marshmallow as ma

from typing import List
from ..cleanup_none_mixin import CleanupNoneMixin
from ..api.collection import CollectionSchema
from ..api.data_type import DataTypeSchema
from ..api.storage_gateway import StorageGatewaySchema
from ..api.user_credential import UserCredentialSchema


IRODS_CONNECTOR_ID = "e47b6920-ff57-11ea-8aaa-000c297ab3c2"


class EnvironmentSchema(ma.Schema):
    name = ma.fields.String(required=True)
    value = ma.fields.String(required=True)


class IrodsStoragePoliciesSchema(ma.Schema, CleanupNoneMixin):
    _DATA_TYPE = "irods_storage_policies#1.0.0"
    DATA_TYPE = ma.fields.Str(
        required=True,
        allow_none=False,
        default=_DATA_TYPE,
        validate=[ma.validate.Equal(_DATA_TYPE)],
    )
    irods_environment_file = ma.fields.String(required=True)
    irods_authentication_file = ma.fields.String()
    environment = ma.fields.List(ma.fields.Nested(EnvironmentSchema))
    private = ["irods_environment_file", "irods_authentication_file", "environment"]
    connector_id = IRODS_CONNECTOR_ID


class IrodsCollectionPoliciesSchema(ma.Schema):
    _DATA_TYPE = "irods_collection_policies#1.0.0"
    DATA_TYPE = ma.fields.String(
        required=True,
        allow_none=False,
        default=_DATA_TYPE,
        validate=[ma.validate.Equal(_DATA_TYPE)],
    )
    connector_id = IRODS_CONNECTOR_ID
    private = []  # type: List[str]


class IrodsUserCredentialPoliciesSchema(ma.Schema):
    _DATA_TYPE = "irods_user_credential_policies#1.0.0"
    DATA_TYPE = ma.fields.Str(
        required=True,
        allow_none=False,
        default=_DATA_TYPE,
        validate=[ma.validate.Equal(_DATA_TYPE)],
    )
    connector_id = IRODS_CONNECTOR_ID
    private = []  # type: List[str]


irods_storage_policies_schema = IrodsStoragePoliciesSchema(
    load_only=IrodsStoragePoliciesSchema.private
)
irods_storage_policies_private_schema = IrodsStoragePoliciesSchema()
irods_user_credential_policies_schema = IrodsUserCredentialPoliciesSchema(
    load_only=IrodsUserCredentialPoliciesSchema.private
)
irods_collection_policies_schema = IrodsCollectionPoliciesSchema(
    load_only=IrodsCollectionPoliciesSchema.private
)
irods_collection_policies_private_schema = IrodsCollectionPoliciesSchema()

DataTypeSchema.register_schema(irods_storage_policies_schema)
DataTypeSchema.register_schema(irods_user_credential_policies_schema)
DataTypeSchema.register_schema(irods_collection_policies_schema)

StorageGatewaySchema.register_schema(
    public=irods_storage_policies_schema, private=irods_storage_policies_private_schema
)

UserCredentialSchema.register_schema(public=irods_user_credential_policies_schema)

CollectionSchema.register_schema(
    public=irods_collection_policies_schema,
    private=irods_collection_policies_private_schema,
)
