"""Load default storage types

Revision ID: f4f92276c1c8
Revises: ffcb9848f6a8
Create Date: 2017-01-29 18:31:37.179956

"""
from alembic import op
import sqlalchemy as sa

from datetime import datetime
import json

# revision identifiers, used by Alembic.
revision = 'f4f92276c1c8'
down_revision = 'ffcb9848f6a8'
branch_labels = None
depends_on = None

STORAGE_TYPES = [
    {
        'id': '976cf0cf-78c3-4aab-82d2-7c16adbcc281',
        'display_name': 'Google Drive',
        'enabled': 1,
        'storage_policies': {
            'identity_providers': [],
            'domains': []
        }
    },
    {
        'id': '145812c8-decc-41f1-83cf-bb2a85a2a70b',
        'display_name': 'POSIX',
        'enabled': 0
    },
    {
        'id': '7e3f3f5e-350c-4717-891a-2f451c24b0d4',
        'display_name': 'SpectraLogic BlackPearl',
        'enabled': 0
    },
    {
        'id': '7643e831-5f6c-4b47-a07f-8ee90f401d23',
        'display_name': 'AWS S3',
        'enabled': 0
    },
    {
        'id': '1b6374b0-f6a4-4cf7-a26f-f262d9c6ca72',
        'display_name': 'Ceph S3',
        'enabled': 0
    },
    {
        'id': 'fb656a17-0f69-4e59-95ff-d0a62ca7bdf5',
        'display_name': 'HPSS',
        'enabled': 0
    },
    {
        'id': 'ba09188f-802a-4bed-820f-6d2e222b9323',
        'display_name': 'HDFS',
        'enabled': 0
    },
    {
        'id': '73651282-d5a5-4121-93c7-eb4682948329',
        'display_name': 'iRODS',
        'enabled': 0
    }
]


def upgrade():
    conn = op.get_bind()
    sql = sa.text(
        'insert into storage_type(id, display_name, enabled, '
        'credential, storage_policies, created_at, updated_at) '
        'values(:id, :display_name, :enabled, NULL, :policies, :now, :now)')

    for st in STORAGE_TYPES:
        conn.execute(sql,
                     id=st['id'],
                     display_name=st['display_name'],
                     enabled=st['enabled'],
                     policies=json.dumps(st.get('storage_policies', {})),
                     now=str(datetime.utcnow()))


def downgrade():
    conn = op.get_bind()
    sql = sa.text('delete from storage_type where id = :id')

    for st in STORAGE_TYPES:
        conn.execute(sql, id=st['id'])
